Stan Math Library: stan::math::include_summand< propto, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10 > Struct Template Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Types | List of all members
stan::math::include_summand< propto, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10 > Struct Template Reference

Template metaprogram to calculate whether a summand needs to be included in a proportional (log) probability calculation. More...

`#include <include_summand.hpp>`

## Public Types
enum | { value }
| `true` if a term with the specified propto value and subterm types should be included in a proportionality calculation. More...

## Detailed Description

### template<bool propto, typename T1 = double, typename T2 = double, typename T3 = double, typename T4 = double, typename T5 = double, typename T6 = double, typename T7 = double, typename T8 = double, typename T9 = double, typename T10 = double>
struct stan::math::include_summand< propto, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10 >

Template metaprogram to calculate whether a summand needs to be included in a proportional (log) probability calculation.

For usage, the first boolean parameter should be set to `true` if calculating a term up to proportionality. Other type parameters should be included for all of the types of variables in a term.

The `value` enum will be `true` if the `propto` parameter is `false` or if any of the other template arguments are not constants as defined by `stan::is_constant<T>`.

Template Parameters

  propto | `true` if calculating up to a proportionality constant.
  T1 | First

Definition at line 36 of file include_summand.hpp.

## Member Enumeration Documentation

template<bool propto, typename T1 = double, typename T2 = double, typename T3 = double, typename T4 = double, typename T5 = double, typename T6 = double, typename T7 = double, typename T8 = double, typename T9 = double, typename T10 = double>

anonymous enum

`true` if a term with the specified propto value and subterm types should be included in a proportionality calculation.

Enumerator
value |

Definition at line 42 of file include_summand.hpp.

The documentation for this struct was generated from the following file:

- stan/math/prim/scal/meta/include_summand.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.